Learn R Programming

NSO1212 (version 1.4.0)

NSO1212: National Statistical Office of Mongolia's Open Data API Handler

Description

National Statistical Office of Mongolia (NSO) is the national statistical service and an organization of Mongolian government. NSO provides open access and official data via its open-data API. The package NSO1212 has functions for accessing the API service. The functions are compatible with the API v2.0 and get data-sets or its detailed information from the API.

Arguments

References

http://opendata.1212.mn/en/doc